#
# spec file for package schismtracker
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           schismtracker
Version:        20190805
Release:        bp153.1.74
Summary:        Music editor that matches the look and feel of Impulse Tracker
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            http://schismtracker.org/

#Git-Clone:     https://github.com/schismtracker/schismtracker
Source:         https://github.com/schismtracker/schismtracker/archive/%version.tar.gz
Source2:        %name.desktop
Patch1:         schism-alsa.diff
Patch2:         schism-nodate.diff
Patch3:         schism-deptrack.diff
BuildRequires:  SDL-devel >= 1.2.10
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  python >= 2.4
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xv)

%description
Schism Tracker is a reimplementation of Impulse Tracker, a
program used to create music without the requirements of
specialized, expensive equipment, and with a unique "finger feel"
that is difficult to replicate in-part. The player is based on a
modified version of the Modplug engine, with a number of
bugfixes and changes to improve IT playback.

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
b="%buildroot"
%make_install
for size in 16 22 24 32 36 48 64 72 96 128 192; do
	install -Dm 0644 "icons/schism-icon-$size.png" \
		"$b/%_datadir/icons/hicolor/${size}x$size/apps/%name.png"
done
install -Dm 0644 icons/schism-icon.svg \
	"$b/%_datadir/icons/hicolor/scalable/apps/%name.svg"
# install desktop file
%suse_update_desktop_file -i %name

%files
%defattr(-,root,root)
%license COPYING
%doc NEWS README.md
%_bindir/schismtracker
%_datadir/icons/hicolor
%_datadir/applications/*
%_datadir/pixmaps/*
%_mandir/man*/*

%changelog
* Sun Aug 18 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 20190805
  * fixed CVE-2019-14524 [boo#1144261]: heap overflow in
    MTM loader
  * fixed CVE-2019-14523 [boo#1144266]: heap overflow in
    Oktalyzer loader
  * support 15-channel MOD files
  * Support undocumented MIDI macro characters, and support
    character p (MIDI program) properly.
* Thu Feb  8 2018 jengelh@inai.de
- Get rid of BuildRequires: xorg-x11-devel.
* Wed Feb  7 2018 jengelh@inai.de
- Update to new upstream release 20170910
  * Make MIDI note entry reliable
  * Stop restricting instrument in MIDI note entry based on MIDI
    channel (this was nonsense)
  * Fix note off events in MIDI output
  * Improve S3M AdLib emulation
  * Allow navigating the Load Instrument screen by holding up or
    down, just like on the Load Sample and Load Module screens
  * Support ADPCM samples in MOD files
  * Detect Cheesetracker and old OpenMPT modules
* Thu Apr  9 2015 jengelh@inai.de
- Update to new snapshot 20150409
  * ping-pong effect was wrongly mixed together
  * support for loading 24-bit stereo WAV samples
  * use OpenMPT filters
* Sun Oct  5 2014 jengelh@inai.de
- Update to new snapshot 20140419
  * reset panning after S91 if sample/instrument has a default
  panning set
  * add timestamp sorting mode; hide *~ on all platforms
  * re-add note fade when hitting end of unlooped volume envelope
* Wed Feb  8 2012 jengelh@medozas.de
- Update to new upstream release 20120105
  * Shift-F10 now provides a dialog if the orderlist is empty
  * Fix loop points when deleting last point in envelope
  * Instrument list: Alt-Shift-A on trans table now copies sample
  name as well as assigning sample numbers
  * Less picky sample-replacement checking for pattern-to-sample
  rendering
  * Pattern editor: enter key now does channel search for instrument
  number if none is under the cursor
  * Add hidden option for inverted (more FT2-like) home/end key
  behavior in the pattern editor
  * Fix garbage writing when swapping portamento to the volume column
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Sep 29 2011 idonmez@suse.com
- Add schismtracker-link.patch to link with new ld
* Sat Apr  9 2011 jengelh@medozas.de
- updated to Hg snapshot 20110409
- removed __DATE__/__TIME__ from source (via patch)
* Mon Aug 30 2010 jengelh@medozas.de
- Add a patch to schismtracker that restores sound for
  sound chips that lack hardware mixing capabilities.
* Wed Feb 24 2010 prusnak@suse.cz
- renamed to schismtracker
* Wed Feb 24 2010 jengelh@medozas.de
- updated to Hg snapshot 20100224
* Tue Dec 11 2007 prusnak@suse.cz
- updated to CVS snapshot 20071208
* Thu Nov  1 2007 prusnak@suse.cz
- added desktop and icon files
* Tue Sep 18 2007 prusnak@suse.cz
- created package (initial version 0.4.99.1 = 0.5rc1)
